# ECP5/ECP5-5G Boards

The {py:mod}`torii_boards.lattice.ecp5` module provides a collection of Lattice ECP5/ECP5-5G FPGA development boards, they are based off the Torii {py:class}`ECP5Platform <torii.platform.vendor.lattice.ecp5.ECP5Platform>` platform and support the [Trellis] and [Diamond] toolchains.

```{eval-rst}
.. autoclass:: torii_boards.lattice.ecp5.Colorlight_5A75B_R70Platform
  :members:

.. autoclass:: torii_boards.lattice.ecp5.ECP55GEVNPlatform
  :members:

.. autoclass:: torii_boards.lattice.ecp5.ECPIX545Platform
  :members:

.. autoclass:: torii_boards.lattice.ecp5.ECPIX585Platform
  :members:

.. autoclass:: torii_boards.lattice.ecp5.LogicbonePlatform
  :members:

.. autoclass:: torii_boards.lattice.ecp5.Logicbone85FPlatform
  :members:

.. autoclass:: torii_boards.lattice.ecp5.OrangeCrabR0_1Platform
  :members:

.. autoclass:: torii_boards.lattice.ecp5.OrangeCrabR0_2_25FPlatform
  :members:

.. autoclass:: torii_boards.lattice.ecp5.OrangeCrabR0_2_85FPlatform
  :members:

.. autoclass:: torii_boards.lattice.ecp5.Supercon19BadgePlatform
  :members:

.. autoclass:: torii_boards.lattice.ecp5.ULX3S_12F_Platform
  :members:

.. autoclass:: torii_boards.lattice.ecp5.ULX3S_25F_Platform
  :members:

.. autoclass:: torii_boards.lattice.ecp5.ULX3S_45F_Platform
  :members:

.. autoclass:: torii_boards.lattice.ecp5.ULX3S_85F_Platform
  :members:

.. autoclass:: torii_boards.lattice.ecp5.VersaECP55GPlatform
  :members:

.. autoclass:: torii_boards.lattice.ecp5.VersaECP5Platform
  :members:
```

[Trellis]: https://github.com/YosysHQ/prjtrellis
[Diamond]: https://www.latticesemi.com/latticediamond
